==> uriel-1.9.2.tgz: package/app/lib/logger.js <==
// app/lib/logger.js

// Dependencies
const __ = require('@mediaxpost/lodashext');
const fs = require('fs');
const winston = require('winston');

/**
 * A utility class to wrap Winston logging
 * @class Logger
 * @param {object} config - A global configuration object that may contain options on how to initialize the logger
 * @example
 * let logger = new logger(config);
 */
class Logger {
  constructor(config) {
    this.logDir = config.logging.logDir || './logs';

    const transports = [
      new winston.transports.File({
        filename: `${this.logDir}/info.log`,
        name: 'info-log',
        level: 'info',
        formatter: this.formatter
      }),
      new winston.transports.File({
        filename: `${this.logDir}/error.log`,
        name: 'error-log',
        level: 'error',
        formatter: this.formatter
      })
    ];

    // Optimization -- Add console logging if not in production
    // if ((process.env.NODE_ENV !== 'production') && (process.env.NODE_ENV !== 'test')) {
    transports.push(new winston.transports.Console({ level: 'debug', formatter: this.formatter }));

    // transports.push(
    //   new (winston.transports.File) ({
    //     filename: this.logDir + '/debug.log',
    //     name: 'debug-log',
    //     level: 'debug',
    //     formatter: this.formatter
    //   })
    // );
    // }
    this.options = {
      exitOnError: false,
      formatter: this.formatter,
      transports: transports
    };

    // Create log folder if it does not already exist
    if (!fs.existsSync(config.logging.logDir)) {
      console.log('Creating log folder');
      fs.mkdirSync(config.logging.logDir);
    }

    // Merge options from config into this object
    this.options = __.assign(this.options, config.logging.options);
    this.log = new winston.Logger(this.options);
  }

  formatter(options) {
    return `${new Date().toISOString()} [${options.level.toUpperCase()}]: ${options.message}`;
  }

  handleError(err) {
    if (this.log) {
      this.log.error(err);
    }
  }
}

module.exports = Logger;

==> uriel-2.0.1.tgz: package/app/lib/logger.js <==
// app/lib/logger.js

// Dependencies
const __ = require('@outofsync/lodash-ex');
const fs = require('fs');
const winston = require('winston');
const { format } = winston;

/**
 * A utility class to wrap Winston logging
 * @class Logger
 * @param {object} config - A global configuration object that may contain options on how to initialize the logger
 * @example
 * let logger = new logger(config);
 */
class Logger {
  constructor(config) {
    this.logDir = config.logging.logDir || './logs';

    const transports = [
      new winston.transports.File({
        filename: `${this.logDir}/info.log`,
        name: 'info-log',
        level: 'info',
        format: format.printf(this.formatter)
      }),
      new winston.transports.File({
        filename: `${this.logDir}/error.log`,
        name: 'error-log',
        level: 'error',
        format: format.printf(this.formatter)
      })
    ];

    // Optimization -- Add console logging if not in production
    // if ((process.env.NODE_ENV !== 'production') && (process.env.NODE_ENV !== 'test')) {
    transports.push(new winston.transports.Console({ level: 'debug', formatter: this.formatter }));

    this.options = {
      exitOnError: false,
      format: winston.format.printf(this.formatter),
      transports: transports
    };

    // Create log folder if it does not already exist
    if (!fs.existsSync(config.logging.logDir)) {
      console.log('Creating log folder');
      fs.mkdirSync(config.logging.logDir);
    }

    // Merge options from config into this object
    this.options = __.assign(this.options, config.logging.options);
    this.log = winston.createLogger(this.options);
  }

  formatter(options) {
    let message = options.message;
    if (!message) {
      message = JSON.parse(options[Symbol.for('message')])['@message'];
    }
    return `${new Date().toISOString()} [${options.level.toUpperCase()}]: ${message}`;
  }

  handleError(err) {
    if (this.log) {
      this.log.error(err);
    }
  }
}

module.exports = Logger;
